
/* Generated data (by glib-mkenums) */

#include <glib-object.h>

/* enumerations from "/home/paolo/workspace/file-roller/src/typedefs.h" */
#include "/home/paolo/workspace/file-roller/src/typedefs.h"
GType
fr_compression_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { FR_COMPRESSION_VERY_FAST, "FR_COMPRESSION_VERY_FAST", "very-fast" },
      { FR_COMPRESSION_FAST, "FR_COMPRESSION_FAST", "fast" },
      { FR_COMPRESSION_NORMAL, "FR_COMPRESSION_NORMAL", "normal" },
      { FR_COMPRESSION_MAXIMUM, "FR_COMPRESSION_MAXIMUM", "maximum" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("FrCompression", values);
  }
  return etype;
}

/* Generated data ends here */

